@@ -8,6 +8,11 @@ START_LOG="$LOG_DIR/start.log"
 CODEX_STAMP_FILE="$ROOT_DIR/state/npm_codex_install.stamp"
 CODEX_INSTALL_TTL="${CODEX_INSTALL_TTL:-86400}"
 
+# 统一重启信号文件路径：使用配置目录而非代码目录
+# 这样 pipx 安装的 master 和源码运行的 master 可以共享同一个信号文件
+MASTER_CONFIG_ROOT="${MASTER_CONFIG_ROOT:-$HOME/.config/vibego}"
+export MASTER_RESTART_SIGNAL_PATH="$MASTER_CONFIG_ROOT/state/restart_signal.json"
+
 log_line() {
   local ts
   ts=$(date '+%Y-%m-%d %H:%M:%S%z')
